@@ -3,10 +3,34 @@ import pickle
 import torch
 
 from dltranz.data_load import padded_collate, TrxDataset
-from dltranz.trx_encoder import TrxEncoder, TrxMeanEncoder
+from dltranz.trx_encoder import PaddedBatch, TrxEncoder, TrxMeanEncoder
 from .test_data_load import gen_trx_data
 
 
+def test_padded_batch_mask_tensor():
+    data = PaddedBatch(torch.randn(4, 5, 3), torch.tensor([2, 5, 1, 3]))
+    out = data.seq_len_mask
+    exp = torch.tensor([
+        [1, 1, 0, 0, 0],
+        [1, 1, 1, 1, 1],
+        [1, 0, 0, 0, 0],
+        [1, 1, 1, 0, 0]
+    ]).long()
+    torch.testing.assert_close(out, exp)
+
+
+def test_padded_batch_mask_dict():
+    data = PaddedBatch({'col1': torch.randn(4, 5), 'col2': torch.randn(4, 5)}, torch.tensor([4, 5, 1, 3]))
+    out = data.seq_len_mask
+    exp = torch.tensor([
+        [1, 1, 1, 1, 0],
+        [1, 1, 1, 1, 1],
+        [1, 0, 0, 0, 0],
+        [1, 1, 1, 0, 0]
+    ]).long()
+    torch.testing.assert_close(out, exp)
+
+
 def test_simple():
     x, y = padded_collate(TrxDataset(gen_trx_data([4, 3, 2])))
 
